@@ -48,6 +48,6 @@ class Domoticz(IPlugin):
 #				bod == rs['boy']
 #				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
 		return {"plugin": "Domoticz",
-			"method": "switchlight",
+			"method": "switchlight"
 #			"body": bod
 		}
